# dispycos: Node Status

Name |
IP Address |
Status |
Servers |
Available CPU | Unknown
Available Memory | Unknown
Available Swap Space | Unknown
Available Disk Space | Unknown
Tasks Submitted |
Tasks Running |
Tasks Done |
Last Update |

Servers
| Server | Tasks | Last Update
--- | --- | --- | ---
Submitted | Running | Done

Update Interval Seconds : |
Name or IP of Node to Show : |

Selected Servers :